@@ -1,4 +1,4 @@
-use crate::imp::history::diff_and_cache::diff_value::DiffValue;
+use crate::imp::history::diff_and_cache::diff_value::{DiffValue};
 use crate::error::FsResult;
 use crate::test_simple_history::simple_diff::sd_diff::SdDiff;
 use std::io::{Read, Write};
@@ -13,4 +13,5 @@ impl DiffValue for SdDiff{
     fn write_value<W: Write>(&self, write: &mut W) -> FsResult<()> {
         self.encode(write)
     }
-}
\ No newline at end of file
+}
+
